/*
 * Copyright FinanceScout24 AG
 *
 * $Author: ckolb $
 *
 * $Date: 2004/12/02 18:00:59 $
 *
 * $Log: DeploymentServiceBean.java,v $
 * Revision 1.1  2004/12/02 18:00:59  ckolb
 * Remote-Deployment: Ant-Task und DeploymentServiceBean
 *
 */

package org.jbpm.ejb.impl;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.jar.JarInputStream;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

import org.apache.log4j.Logger;
import org.jbpm.DefinitionService;
import org.jbpm.JbpmConfiguration;
import org.jbpm.JbpmServiceFactory;

/**
 *
 * @ejb.bean type="Stateless"
 *           name="DeploymentServiceBean"
 *           display-name="Integration der Workflow-Komponente"
 *           view-type="remote"
 *           jndi-name="ejb/DeploymentServiceBean"
 * 
 * @ejb.home
 *   remote-class="org.jbpm.ejb.DeploymentServiceRemoteHome"
 *
 * @ejb.interface
 *   remote-class="org.jbpm.ejb.DeploymentServiceRemote"
 * 
 * @jboss.cluster-config partition-name="${jboss.partition.name}"
 * 
 * @version $Revision: 1.1 $, $Date: 2004/12/02 18:00:59 $
 */

public class DeploymentServiceBean implements SessionBean
{

    SessionContext sessionContext = null;

    private static final Logger logger = Logger.getLogger(DeploymentServiceBean.class);

    public void setSessionContext(SessionContext ctx)
    {
        sessionContext = ctx;
    }

    /**
     * Called by the container when the bean is activated.
     */
    public void ejbActivate()
    {
    }

    /**
     * Called by the container when the bean is passivated.
     */
    public void ejbPassivate()
    {
    }

    /**
     * Called by the container when the bean is destroyed.
     */
    public void ejbRemove()
    {
    }

    /**
     * Called by the container to create the bean when a client calls EJBWithSinkHome.create()
     */
    public void ejbCreate() throws CreateException
    {
        JbpmConfiguration.configure( DeploymentServiceBean.class.getClassLoader(), "jbpm.server.properties" );
        JbpmServiceFactory jbpmServiceFactory = JbpmServiceFactory.getInstance();        
    }

    /**
     * 
     * @ejb.interface-method
     */
    public void deploy(byte[] parFile)
    {
        ByteArrayInputStream bis = new ByteArrayInputStream(parFile);
        DefinitionService definitionService = null;
        try
        {
            JbpmServiceFactory serviceLocator = JbpmServiceFactory.getInstance();
            definitionService = serviceLocator.openDefinitionService();
            JarInputStream jarInputStream = new JarInputStream(bis);
            definitionService.deployProcessArchive(jarInputStream);

        }
        catch (Exception e)
        {
            e.printStackTrace();
            throw new EJBException("Fehler beim Deployment des Workflow-Archivs." + e.getMessage(), e);
        }
        finally
        {
            if (definitionService != null)
            {
                definitionService.close();
            }
            if (bis != null)
            {
                try
                {
                    bis.close();
                }
                catch (IOException e1)
                {
                    // Das ignorieren wir
                }
            }
            
        }
    }

}